@@ -1,5 +1,5 @@
 package Koha::Contrib::Mirabel;
-$Koha::Contrib::Mirabel::VERSION = '0.0.4';
+$Koha::Contrib::Mirabel::VERSION = '0.0.5';
 # ABSTRACT: Synchronise un catalogue Koha avec Mir@bel
 use Moose;
 
@@ -58,6 +58,11 @@ sub update {
     say '_' x 40, " #$biblionumber" if $self->verbose;
 
     my $record = GetMarcBiblio($biblionumber);
+    unless ($record) {
+        say 'ERREUR: Notice présente dans Mir@bel mais supprimée du Catalogue Koha'
+            if $self->verbose;
+        return;
+    }
     $record = MARC::Moose::Record::new_from($record, 'Legacy');
     print $record->as('Text') if $self->verbose;
 
@@ -233,7 +238,7 @@ Koha::Contrib::Mirabel - Synchronise un catalogue Koha avec Mir@bel
 
 =head1 VERSION
 
-version 0.0.4
+version 0.0.5
 
 =head1 ATTRIBUTES
 
@@ -282,7 +287,7 @@ Frédéric Demians <f.demians@tamil.fr>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Frédéric Demians.
+This software is copyright (c) 2015 by Frédéric Demians.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
